data {
    int N;		//	The number of trials
    int Res[N];		//	Responses:  
//	1 denotes -, 2 denotes ?, 3 denotes +
    real X[N];		//	Stimuli
    real min_sgm;	//	The lower boundary of sgm
    real max_sgm;	//	The upper boundary of sgm
}
parameters {
    real<lower = 0.0> sgm;
    real C1;
    real<lower = 0.0> w_C;
}
transformed parameters {
    real C2;
    vector[3] p[N];		//	Probabilities for X[N]
    
    C2 = C1 + w_C;
    for (i in 1:N){
        p[i][1] = 1 - Phi((X[i] - C1) / sgm);
        p[i][2] = Phi((X[i] - C1) / sgm) - Phi((X[i] - C2) / sgm);
        p[i][3] = Phi((X[i] - C2) / sgm);
    }
}
model {
    sgm ~ uniform(min_sgm, max_sgm);
    for (i in 1:N)
        Res[i] ~ categorical(p[i]);
}
generated quantities {
    real mu;
    real C;
    
    mu = (C1 + C2) / 2;
    C = C2 - mu;
}
