import numpy as np
import scipy

f_phi = scipy.stats.norm.cdf    #   Cumulative standard normal distribution function


class PF:
    """
            Psychometric function with the parameters mu and sigma
    """
    def __init__(self, mu, sgm):
        self.mu = mu
        self.sgm = sgm

    def v(self, x):
        return f_phi((x - self.mu) / self.sgm)


def bisect( f, c, Lb, Ub ):
    """
            Return the value root so that f(root) = c
    """
    s = 1.0 if f(Ub) > f(Lb) else -1.0      #   s = 1 when f(x) is an increasing functin
    while ((abs(Ub - Lb) > (1.0e-15) * (abs(Ub) + abs(Lb)))
        and
          (abs(Ub) + abs(Lb) > 1.0e-14)):
              m = 0.5 * (Ub + Lb)
              if (s * (f(m) - c)) > 0.0:
                  Ub = m
              else:
                  Lb = m
 
    return 0.5 * (Ub + Lb)
 
def my_kernel(x, y, w_k):
    return np.exp(-((x - y) / w_k) ** 2)


def k_ave(v, X, W, w_k):
    n = len(X)
    num = 0.0
    den = 0.0
    for i in range(n):
        k_v = my_kernel(v, X[i], w_k)
        num += W[i] * k_v
        den += k_v
    return num / den



